@@ -55,6 +55,9 @@ def archive(trace, config, jobname, tempdir, build_folder, success):
             if when == "on_failure" and success:
                 return None
 
+        if "paths" not in job_config["artifacts"]:
+            return None
+
         trace.writeline("\nFinding artifacts...")
 
         paths = job_config["artifacts"]["paths"]
