@@ -55,19 +55,20 @@ if installer is not None:
     parser.add_argument("--user", type=str, default=None,
                         help="User to use for --install")
 
-    parser.add_argument("--uninstall", action="store_true", default=False,
+    parser.add_argument("--uninstall", action="store_true", default=False, dest="uninstall",
                         help="Remove boot-time startup scripts (undo --install)")
 
 
 def run():
     opts = parser.parse_args()
 
-    if opts.uninstall:
-        installer.uninstall()
-        return
-    if opts.install:
-        installer.install(opts.install, opts.user)
-        return
+    if installer:
+        if opts.uninstall:
+            installer.uninstall()
+            return
+        if opts.install:
+            installer.install(opts.install, opts.user)
+            return
 
     if opts.register:
         if not opts.desc:
