@@ -1,6 +1,7 @@
 """
 File-like trace bufffer that sends to gitlab
 """
+import os
 
 
 class TraceProxy(object):
@@ -24,6 +25,15 @@ class TraceProxy(object):
             data = data.encode()
         self.offset = self.runner.trace(self, data, offset=self.offset)
 
+    def writeline(self, text):
+        """
+        Write a message on it's own line
+        :param text:
+        :return:
+        """
+        text = str(text) + os.linesep
+        self.write(text)
+
     def flush(self):
         """
         Flush the buffer
